from transformers import AutoModelForCausalLM, AutoTokenizer


class GPT2Wrapper:
    def __init__(self, path="./models/DEPOTxGPT-2", prefix='', sep='<|sep|>'):
        self.model = AutoModelForCausalLM.from_pretrained(path)
        self.tokenizer = AutoTokenizer.from_pretrained(path)
        self.prefix = prefix
        self.sep = sep

    def get_input_sent(self, vulg, euph=None):
        if euph:
            return self.prefix + vulg + self.sep + euph + "<|endoftext|>"
        else:
            return self.prefix + vulg + self.sep

    def get_output_sent(self, output):
        sent = output
        while sent.find(self.sep) != -1:
            sent = sent[sent.find(self.sep)+len(self.sep)+1:]
        sent = sent[:-13]
        return sent

    def process(self, text):
        input_ids = self.tokenizer.encode(
            self.get_input_sent(text),
            return_tensors="pt"
        )

        output_ids = self.model.generate(
            input_ids,
            min_length=5,
            max_length=3*len(input_ids[0]),
            num_return_sequences=1,
            pad_token_id=self.tokenizer.pad_token_id,
            sep_token_id=self.tokenizer.sep_token_id,
            eos_token_id=self.tokenizer.eos_token_id
        )

        return self.get_output_sent(
            self.tokenizer.decode(
                output_ids[0],
                skip_special_tokens=False
            )
        )
