import os
import shutil
import subprocess


models_dir = 'devulgarizer/models'
model_urls = [
    "http://mozart.ipipan.waw.pl/~cklamra/DEPOTx/models/DEPOTxGPT-2.zip",
    "http://mozart.ipipan.waw.pl/~cklamra/DEPOTx/models/DEPOTxT5-base.zip",
    "http://mozart.ipipan.waw.pl/~cklamra/DEPOTx/models/DEPOTxT5-large.zip"
]


def execute_command(command):
    process = subprocess.Popen(
        command,
        stdin=subprocess.PIPE,
        stdout=subprocess.PIPE,
        text=True,
        shell=True)

    while process.poll() is None:
        line = process.stdout.readline()
        if line.strip():
            print(line)


def download_model(url, dir):
    filename = os.path.basename(url)
    filepath = os.path.join(dir, filename)
    print(f"Downloading {filename}")
    execute_command(f"wget -O {filepath} {url}")

    print(f"Extracting {filename}")
    shutil.unpack_archive(filepath, extract_dir=dir)
    os.remove(filepath)


def main():
    if not os.path.exists(models_dir):
        os.mkdir(models_dir)

    for url in model_urls:
        download_model(url, models_dir)

    print(f"Models downloaded to {os.path.join(os.getcwd(), models_dir)}")


if __name__ == '__main__':
    main()
