import argparse
import pandas as pd
from . import evaluate


def main():
    parser = argparse.ArgumentParser()
    parser.add_argument(
        '-o', type=str, required=True,
        help="path to the file containing original sentences")
    parser.add_argument(
        '-t', type=str, required=True, nargs='+',
        help="paths to the files containing transfered sentences to be evaluated")
    parser.add_argument(
        '-s', type=str, required=False,
        help="output file path (CSV)")
    args = parser.parse_args()

    with open(args.o, 'r') as f:
        original = f.readlines()[:100]

    data = pd.DataFrame({'text': original})
    for file in args.t:
        with open(file, 'r') as f:
            transfered = f.readlines()[:100]
        data[file] = transfered

    results = evaluate(data).transpose()

    if args.s is not None:
        results.to_csv(
            args.s,
            header=False
        )

    results.columns = ['' for _ in results.columns]
    print(results)


if __name__ == '__main__':
    main()
