from nltk.translate import bleu_score
from sentence_transformers import util


def tokenize(text, spacy, lemmatize=False):
    if lemmatize:
        return [token.lemma_ for token in spacy(text)]
    else:
        return [token.text for token in spacy(text)]


def word_overlap(original_sentence, transfered_sentence, spacy):
    tokens_o = tokenize(original_sentence, spacy, lemmatize=True)
    tokens_t = tokenize(transfered_sentence, spacy, lemmatize=True)

    union = set(tokens_o + tokens_t)
    intersection = list(set(tokens_o) & set(tokens_t))

    return len(intersection) / len(union)


def corpus_bleu(original_sentences, transferred_sentences):
    references = []
    hypotheses = []

    for sentence in original_sentences:
        references.extend([[sentence]])
    for sentence in transferred_sentences:
        hypotheses.extend([sentence])

    return bleu_score.corpus_bleu(references, hypotheses, weights=[1])


def cosine_similarity(original_text, transfered_text, sbert):
    embeddings_o = sbert.encode(original_text)
    embeddings_t = sbert.encode(transfered_text)

    cosine_score = util.pytorch_cos_sim(embeddings_o, embeddings_t)
    return cosine_score.item()
