import numpy as np
from transformers import AutoModelForCausalLM, AutoTokenizer
import torch


class GPT2Wrapper:
    def __init__(self, model="flax-community/papuGaPT2"):
        self.device = torch.device("cuda" if torch.cuda.is_available()
                                   else "cpu")
        self.tokenizer = AutoTokenizer.from_pretrained(model)
        self.model = AutoModelForCausalLM.from_pretrained(model)
        self.model.to(self.device)

    def get_sentence_ppl(self, sentence):
        tokenize_input = self.tokenizer.encode(sentence)
        tensor_input = torch.tensor([tokenize_input]).to(self.device)
        with torch.no_grad():
            loss = self.model(tensor_input, labels=tensor_input)[0]
        return np.exp(loss.detach().numpy())

    def get_corpus_ppl(self, sentences):
        ppl_list = [el for el in [self.get_sentence_ppl(sent)
                                  for sent in sentences if sent != '']
                    if not np.isnan(el)]
        return sum(ppl_list) / len(ppl_list)
