import ctypes
import platform
import os


class GoString(ctypes.Structure):
    _fields_ = [
        ('p', ctypes.c_char_p),
        ('n', ctypes.c_longlong),
    ]


class PrzetakWrapper:
    def __init__(self, gopath, spacy):
        if platform.system() == 'Darwin':
            ext = '.dylib'
        elif platform.system() == 'Windows':
            ext = '.dll'
        else:
            ext = '.so'

        libprzetak = os.path.join(
            gopath,
            'src/github.com/mciura/przetak/libprzetak' + ext
        )

        self.przetak = ctypes.cdll.LoadLibrary(libprzetak)
        self.przetak.version.argtypes = []
        self.przetak.version.restype = GoString
        self.przetak.evaluate.argtypes = [GoString]
        self.przetak.evaluate.restype = ctypes.c_int

        self.spacy = spacy

    def tokenize(self, text):
        return [tok.text for tok in self.spacy(text)]

    def evaluate(self, text):
        b = text if isinstance(text, bytes) else bytes(str(text), 'utf-8')
        pt = ctypes.create_string_buffer(b)

        return self.przetak.evaluate(GoString(pt.raw, ctypes.sizeof(pt)))

    def find(self, text):
        tokens = self.tokenize(text)
        vulgar = [self.evaluate(tok) > 1 for tok in tokens]
        found = [tok for tok, vul in zip(tokens, vulgar) if vul]

        return found

    def delete(self, text):
        output = text
        found = self.find(text)

        while found:
            word = found.pop(0)
            length = len(word)
            start = output.find(word)
            end = start + length

            output = output[:start+1] + "*" * (length-1) + output[end:]

        return output
